==> builders_inventory-2.2.0-sources.jar: _3650/builders_inventory/api/widgets/editbox/MiniMessageEditBox.java <==
package _3650.builders_inventory.api.widgets.editbox;

import java.util.function.Consumer;
import net.minecraft.class_2561;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_342;
import org.jetbrains.annotations.Nullable;

import _3650.builders_inventory.api.minimessage.MiniMessageUtil;
import _3650.builders_inventory.api.minimessage.instance.LastParseListener;
import _3650.builders_inventory.api.minimessage.instance.MMInstanceConstructor;
import _3650.builders_inventory.api.minimessage.instance.MiniMessageInstance;
import _3650.builders_inventory.api.minimessage.widgets.MiniMessageEventListener;
import _3650.builders_inventory.api.minimessage.widgets.wrapper.WrappedTextField;
import _3650.builders_inventory.mixin.feature.minimessage.EditBoxAccessor;

/**
 * @deprecated This widget is not currently used or maintained and may be removed without warning or may be fixed and un-deprecated without warning<br>
 * An {@link class_342} with a {@link MiniMessageInstance} mostly handled within<br>
 * You still need to handle calling the following:<br>
 * {@link #miniMessageTick()}<br>
 * {@link #miniMessageMouseScrolled(double, double, double, double)}<br>
 * {@link #miniMessageMouseClicked(double, double, int)}<br>
 * These are either not possible in a widget or occur outside the widget's area and need full-screen coverage
 */
@Deprecated
public class MiniMessageEditBox extends class_342 implements MiniMessageEventListener {
	
	private Consumer<String> newResponder;
	
	public final MiniMessageInstance minimessage;
	
	public MiniMessageEditBox(MMInstanceConstructor widget, class_327 font, int x, int y, int width, int height, class_2561 message) {
		super(font, x, y, width, height, message);
		this.minimessage = widget.construct(WrappedTextField.editBox(this), LastParseListener.IGNORE);
		this.initMiniMessage();
	}
	
	public MiniMessageEditBox(MMInstanceConstructor widget, class_327 font, int x, int y, int width, int height, @Nullable class_342 editBox, class_2561 message) {
		super(font, x, y, width, height, editBox, message);
		this.minimessage = widget.construct(WrappedTextField.editBox(this), LastParseListener.IGNORE);
		this.initMiniMessage();
	}
	
	private void initMiniMessage() {
		super.method_1863(this::responder);
		MiniMessageUtil.wrapFormatter(this, this.minimessage);
	}
	
	@Override
	public void method_1863(Consumer<String> newResponder) {
		this.newResponder = newResponder;
	}
	
	private void responder(String str) {
		if (!this.minimessage.unknownEdit() && this.newResponder != null) this.newResponder.accept(str);
	}
	
	@Override
	public void method_25365(boolean focused) {
		if (((EditBoxAccessor)this).getCanLoseFocus() || focused) {
			this.minimessage.setActive(focused);
			if (focused) {
				this.minimessage.unknownEdit();
			} else {
				this.method_1887(null);
			}
		}
		super.method_25365(focused);
	}
	
	@Override
	public boolean method_25404(int keyCode, int scanCode, int modifiers) {
		if (this.minimessage.keyPressed(keyCode, scanCode, modifiers)) return true;
		return super.method_25404(keyCode, scanCode, modifiers);
	}
	
	@Override
	public void miniMessageTick() {
		this.minimessage.tick();
	}
	
	@Override
	public boolean miniMessageMouseScrolled(double mouseX, double mouseY, double scrollX, double scrollY) {
		return this.minimessage.mouseScrolled(mouseX, mouseY, scrollX, scrollY);
	}
	
	@Override
	public boolean miniMessageMouseClicked(double mouseX, double mouseY, int button) {
		return this.minimessage.mouseClicked(mouseX, mouseY, button);
	}
	
	@Override
	public void miniMessageRender(class_332 gui, int mouseX, int mouseY) {
		if (this.method_37303() && this.method_25370()) {
			this.minimessage.renderPreviewOrError(gui);
			this.minimessage.renderSuggestions(gui, mouseX, mouseY);
			this.minimessage.renderHover(gui, mouseX, mouseY);
		}
		this.minimessage.renderFormatHover(gui, mouseX, mouseY, 0, this.method_1882().length());
	}
	
}

==> builders_inventory-2.2.6-sources.jar: _3650/builders_inventory/api/widgets/editbox/MiniMessageEditBox.java <==
package _3650.builders_inventory.api.widgets.editbox;

import java.util.function.Consumer;
import net.minecraft.class_11908;
import net.minecraft.class_11909;
import net.minecraft.class_2561;
import net.minecraft.class_327;
import net.minecraft.class_332;
import net.minecraft.class_342;
import org.jetbrains.annotations.Nullable;

import _3650.builders_inventory.api.minimessage.MiniMessageUtil;
import _3650.builders_inventory.api.minimessage.instance.LastParseListener;
import _3650.builders_inventory.api.minimessage.instance.MMInstanceConstructor;
import _3650.builders_inventory.api.minimessage.instance.MiniMessageInstance;
import _3650.builders_inventory.api.minimessage.widgets.MiniMessageEventListener;
import _3650.builders_inventory.api.minimessage.widgets.wrapper.WrappedTextField;
import _3650.builders_inventory.mixin.feature.minimessage.EditBoxAccessor;

/**
 * @deprecated This widget is not currently used or maintained and may be removed without warning or may be fixed and un-deprecated without warning<br>
 * An {@link class_342} with a {@link MiniMessageInstance} mostly handled within<br>
 * You still need to handle calling the following:<br>
 * {@link #miniMessageTick()}<br>
 * {@link #miniMessageMouseScrolled(double, double, double, double)}<br>
 * {@link #miniMessageMouseClicked(double, double, int)}<br>
 * These are either not possible in a widget or occur outside the widget's area and need full-screen coverage
 */
@Deprecated
public class MiniMessageEditBox extends class_342 implements MiniMessageEventListener {
	
	private Consumer<String> newResponder;
	
	public final MiniMessageInstance minimessage;
	
	public MiniMessageEditBox(MMInstanceConstructor widget, class_327 font, int x, int y, int width, int height, class_2561 message) {
		super(font, x, y, width, height, message);
		this.minimessage = widget.construct(WrappedTextField.editBox(this), LastParseListener.IGNORE);
		this.initMiniMessage();
	}
	
	public MiniMessageEditBox(MMInstanceConstructor widget, class_327 font, int x, int y, int width, int height, @Nullable class_342 editBox, class_2561 message) {
		super(font, x, y, width, height, editBox, message);
		this.minimessage = widget.construct(WrappedTextField.editBox(this), LastParseListener.IGNORE);
		this.initMiniMessage();
	}
	
	private void initMiniMessage() {
		super.method_1863(this::responder);
		MiniMessageUtil.addFormatter(this, this.minimessage);
	}
	
	@Override
	public void method_1863(Consumer<String> newResponder) {
		this.newResponder = newResponder;
	}
	
	private void responder(String str) {
		if (!this.minimessage.unknownEdit() && this.newResponder != null) this.newResponder.accept(str);
	}
	
	@Override
	public void method_25365(boolean focused) {
		if (((EditBoxAccessor)this).getCanLoseFocus() || focused) {
			this.minimessage.setActive(focused);
			if (focused) {
				this.minimessage.unknownEdit();
			} else {
				this.method_1887(null);
			}
		}
		super.method_25365(focused);
	}
	
	@Override
	public boolean method_25404(class_11908 event) {
		if (this.minimessage.keyPressed(event)) return true;
		return super.method_25404(event);
	}
	
	@Override
	public void miniMessageTick() {
		this.minimessage.tick();
	}
	
	@Override
	public boolean miniMessageMouseScrolled(double mouseX, double mouseY, double scrollX, double scrollY) {
		return this.minimessage.mouseScrolled(mouseX, mouseY, scrollX, scrollY);
	}
	
	@Override
	public boolean miniMessageMouseClicked(class_11909 event) {
		return this.minimessage.mouseClicked(event);
	}
	
	@Override
	public void miniMessageRender(class_332 gui, int mouseX, int mouseY) {
		if (this.method_37303() && this.method_25370()) {
			this.minimessage.renderPreviewOrError(gui);
			this.minimessage.renderSuggestions(gui, mouseX, mouseY);
			this.minimessage.renderHover(gui, mouseX, mouseY);
		}
		this.minimessage.renderFormatHover(gui, mouseX, mouseY, 0, this.method_1882().length());
	}
	
}
